# deluca-lung

## Getting started
Instructions to provide to students: run the following commands
```
git clone https://github.com/MinRegret/deluca-lung
cd deluca-lung
pip install -e .
jupyter notebook
```

Navigate to the notebook `notebooks/2021-04-13-hello-world.ipynb` and run the cells.